# -*- coding: utf-8 -*-
"""
pdfparanoia.plugins
~~~~~~~~~~~~~~~

Scrubbing machines. Bubbles mandatory.

"""

from .aip import *
from .ieee import *
from .jstor import *
from .rsc import *
from .sciencemagazine import *
